pub struct ScreenState { /* private fields */ }Trait Implementations
Sourceimpl Perform for ScreenState
impl Perform for ScreenState
Sourcefn csi_dispatch(
&mut self,
params: &Params,
intermediates: &[u8],
_ignore: bool,
action: char,
)
fn csi_dispatch( &mut self, params: &Params, intermediates: &[u8], _ignore: bool, action: char, )
A final character has arrived for a CSI sequence Read more
Sourcefn esc_dispatch(&mut self, intermediates: &[u8], _ignore: bool, byte: u8)
fn esc_dispatch(&mut self, intermediates: &[u8], _ignore: bool, byte: u8)
The final character of an escape sequence has arrived. Read more
Sourcefn osc_dispatch(&mut self, params: &[&[u8]], _bell_terminated: bool)
fn osc_dispatch(&mut self, params: &[&[u8]], _bell_terminated: bool)
Dispatch an operating system command.
Sourcefn hook(
&mut self,
_params: &Params,
_intermediates: &[u8],
_ignore: bool,
_action: char,
)
fn hook( &mut self, _params: &Params, _intermediates: &[u8], _ignore: bool, _action: char, )
Invoked when a final character arrives in first part of device control
string. Read more
Sourcefn put(&mut self, _byte: u8)
fn put(&mut self, _byte: u8)
Pass bytes as part of a device control string to the handle chosen in
hook. C0 controls will also be passed to the handler.Sourcefn terminated(&self) -> bool
fn terminated(&self) -> bool
Whether the parser should terminate prematurely. Read more